# mdocfile

[![License](https://img.shields.io/pypi/l/mdocfile.svg?color=green)](https://github.com/alisterburt/mdocfile/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/mdocfile.svg?color=green)](https://pypi.org/project/mdocfile)
[![Python Version](https://img.shields.io/pypi/pyversions/mdocfile.svg?color=green)](https://python.org)
[![CI](https://github.com/alisterburt/mdocfile/actions/workflows/ci.yml/badge.svg)](https://github.com/alisterburt/mdocfile/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/alisterburt/mdocfile/branch/main/graph/badge.svg)](https://codecov.io/gh/alisterburt/mdocfile)

parse serialEM mdoc files in Python
